pub fn on_task_completed(
pool: &ConnPool,
store: Arc<LanceVectorStore>,
task_id: i64,
)Expand description
Called when a TaskCompleted event fires. Reads the task summary and writes it to the knowledge store.
pub fn on_task_completed(
pool: &ConnPool,
store: Arc<LanceVectorStore>,
task_id: i64,
)Called when a TaskCompleted event fires. Reads the task summary and writes it to the knowledge store.